==> rustc-1.81_1.81.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.81.0-src/tests/run-make/cross-lang-lto-riscv-abi/rmake.rs <==
//! Make sure that cross-language LTO works on riscv targets,
//! which requires extra `target-abi` metadata to be emitted.
//@ needs-force-clang-based-tests
//@ needs-llvm-components riscv

// FIXME(#126180): This test doesn't actually run anywhere, because the only
// CI job that sets RUSTBUILD_FORCE_CLANG_BASED_TESTS runs very few tests.

use run_make_support::{bin_name, clang, llvm_readobj, rustc};
use std::{
    env,
    path::PathBuf,
    process::{Command, Output},
    str,
};

fn check_target(target: &str, clang_target: &str, carch: &str, is_double_float: bool) {
    eprintln!("Checking target {target}");
    // Rust part
    rustc()
        .input("riscv-xlto.rs")
        .crate_type("rlib")
        .target(target)
        .panic("abort")
        .linker_plugin_lto("on")
        .run();
    // C part
    clang()
        .target(clang_target)
        .arch(carch)
        .lto("thin")
        .use_ld("lld")
        .no_stdlib()
        .out_exe("riscv-xlto")
        .input("cstart.c")
        .input("libriscv_xlto.rlib")
        .run();

    // Check that the built binary has correct float abi
    let executable = bin_name("riscv-xlto");
    let output = llvm_readobj().input(&executable).file_header().run();
    let stdout = String::from_utf8_lossy(&output.stdout);
    eprintln!("obj:\n{}", stdout);

    assert!(!(is_double_float ^ stdout.contains("EF_RISCV_FLOAT_ABI_DOUBLE")));
}

fn main() {
    check_target("riscv64gc-unknown-linux-gnu", "riscv64-linux-gnu", "rv64gc", true);
    check_target("riscv64imac-unknown-none-elf", "riscv64-unknown-elf", "rv64imac", false);
    check_target("riscv32imac-unknown-none-elf", "riscv32-unknown-elf", "rv32imac", false);
    check_target("riscv32gc-unknown-linux-gnu", "riscv32-linux-gnu", "rv32gc", true);
}

==> rustc-1.83_1.83.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.83.0-src/tests/run-make/cross-lang-lto-riscv-abi/rmake.rs <==
//! Make sure that cross-language LTO works on riscv targets,
//! which requires extra `target-abi` metadata to be emitted.
//@ needs-force-clang-based-tests
//@ needs-llvm-components riscv

//@ needs-force-clang-based-tests
// FIXME(#126180): This test can only run on `x86_64-gnu-debug`, because that CI job sets
// RUSTBUILD_FORCE_CLANG_BASED_TESTS and only runs tests which contain "clang" in their
// name.
// However, this test does not run at all as its name does not contain "clang".

use std::path::PathBuf;
use std::process::{Command, Output};
use std::{env, str};

use run_make_support::{bin_name, clang, llvm_readobj, rustc};

fn check_target(target: &str, clang_target: &str, carch: &str, is_double_float: bool) {
    eprintln!("Checking target {target}");
    // Rust part
    rustc()
        .input("riscv-xlto.rs")
        .crate_type("rlib")
        .target(target)
        .panic("abort")
        .linker_plugin_lto("on")
        .run();
    // C part
    clang()
        .target(clang_target)
        .arch(carch)
        .lto("thin")
        .use_ld("lld")
        .no_stdlib()
        .out_exe("riscv-xlto")
        .input("cstart.c")
        .input("libriscv_xlto.rlib")
        .run();

    // Check that the built binary has correct float abi
    let executable = bin_name("riscv-xlto");
    let output = llvm_readobj().input(&executable).file_header().run();
    let stdout = String::from_utf8_lossy(&output.stdout);
    eprintln!("obj:\n{}", stdout);

    assert!(!(is_double_float ^ stdout.contains("EF_RISCV_FLOAT_ABI_DOUBLE")));
}

fn main() {
    check_target("riscv64gc-unknown-linux-gnu", "riscv64-linux-gnu", "rv64gc", true);
    check_target("riscv64imac-unknown-none-elf", "riscv64-unknown-elf", "rv64imac", false);
    check_target("riscv32imac-unknown-none-elf", "riscv32-unknown-elf", "rv32imac", false);
    check_target("riscv32gc-unknown-linux-gnu", "riscv32-linux-gnu", "rv32gc", true);
}
